Type Alias Mask
Source pub type Mask = Array2<u8>;
A boolean mask indicating for each pixel whether it belongs to the object or not.
pub struct Mask { }
Converts a RLE to its uncompressed mask.
Create a mask from a compressed polygon representation.
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
Performs the conversion.